rule fasta_stats:
    input: 
        fasta_file = expand(rules.filter_length.output.fasta_file, sample_name=SAMPLES,ref_name=REF)
    output: 
        stat_file = f"{frangipane_obj.path_stat_sum}/03_all_fasta-filtered-stats.csv"
    log:
        output =  f"{frangipane_obj.path_logs}/stats/fasta_stats.o",
        error =  f"{frangipane_obj.path_logs}/stats/fasta_stats.e"
    params:
        dir = f"{frangipane_obj.path_filtered_contigs}",
        other_option = frangipane_obj.get_config_value("PARAMS","assembly_stats")
    message:
         f"""--------------------
-Running {{rule}}
|-- Input:
|   - Fasta dir : {{params.dir}}
|-- Output:
|   - stat file: {{output.stat_file}}
|-- Others infos :
|   -LOG error: {{log.error}}
--------------------
"""
    singularity:
        tools_config['SINGULARITY']['TOOLS']
    envmodules:
        tools_config["ENVMODULE"]["ASSEMBLY-STATS"]
    shell:
        """
        cmd="assembly-stats {params.other_option} {params.dir}/*.fa";
        (echo $cmd) > {log.output};
        ($cmd) 1>> {output.stat_file} 2>> {log.error};
        """   